AstroPixImageSource
===================

.. currentmodule:: toasty.pipeline.astropix

.. autoclass:: AstroPixImageSource
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~AstroPixImageSource.deserialize
      ~AstroPixImageSource.fetch_candidate
      ~AstroPixImageSource.get_config_key
      ~AstroPixImageSource.process
      ~AstroPixImageSource.query_candidates

   .. rubric:: Methods Documentation

   .. automethod:: deserialize
   .. automethod:: fetch_candidate
   .. automethod:: get_config_key
   .. automethod:: process
   .. automethod:: query_candidates
